__code__='Gas1]?ZX[c&Dr[^a"_:I9hPFO;5(A\\Te[cCdrmdC1+#h0\'K:YqFA+b77=.ToA4`<:M5(AQ@AY^V,5iGY(jbSYkYl[?Mn%-MF165)g\\q(o=80>A@IA>nk)V@j^W>=j(]iD^!=80-fU`p6&g.@J!&(4aK/<RBR",r["0`*A!8%?X"De13"\'bnT#B1RM4CAE`?,/)N"i(kgpAciJ^(9u>i.lh)!IbH%$1K_.-\\,9Sjnpou\\aKH?$%=1<$UtSe:!Q"-+<,9/Jp@8"Cd#2a.C%WXT5pqVb2FfYS^0p5(![V/ecg)jZ7:IK)GpZI<l[i6,Er-;*D6_0)MI6(fV7&lfk1;G4!``d^r7*:BRjS2-A,,iq+mYP]jk)GC\'0J*aR7Q\\Jt%$05U9?BM/?(Zo<7?Vk/.FV8*bBf4`\\be@9;_ZCK3"JZUH*;;5,)3ZuR&QPThR$EP=Li[Z`pA[4%r&*#6Yr<l(,<m[CcaD(et!Dmn2ckU=`\'PO11r2`iLK/E>H)NW[ZE?-s7<[H2!<&[ZpM$-(EfbI6l#;k1e=?Ln\'XP9<%P;/M2k=QdmP)fD1^cto#daLj;K()us7RAEN&_7%&A4W`<SD?k>)Kegarg6j.J:tt6[SDTphflt-diSgK2Wm*NUG/JFgg4VKU$?uFkLaRb6d_nnG/Z2aI#V/TTU]1BM+U)!_j:sWMWD\\pRfAplEmh^07s&QmoinA/O*_;Q;Ai`Y\'-&G6d\\o)c3e[`V2W,I2aKq$&`I[]JNqJpb,j,J4A6t\'^A(%)79F=D0=0Nu25F7gl>gT+\\2FaNKphL&RMcVPZ.>,ij(.A?EAqShXFQqu"@3!jNST-1UU97lDT746lSiI7$XefCQ\'DnYAcrN*cOopjCBrk2e&<Mqk(h?foY+p\\\'O[-OK/TC9mcU-"Uu6q-snIM/JseY6+hk)7ck2<^3kI_gnf-E9#a"T[kICb83oR6baZ)n%5]M8;m:I(qBC2;M`m[Gm,0Lf-oR]?4^6Y9\\=[$*>\\2N_gaF(`ZBr3N[><pObFPW!_3egp.N+3R1:&?]"s)196$+:G$/DqbqqA^u>)EQRFIC(PUPa`JS=IrrQ5cAIe~>'



__code__='GatU0D/[on&>$QoP,!^B!gL0+GmQO3p5Y4M[8hq7*oTP.Np$rY*)r6afd%n.g[+>S(Fa_5M(eg\'rG.s,gQ3,K88u%"?LQ1`o?=:K67@<S1k2E;rZQiZ@7ZR$\'gMe<!T!f=)[]Dn=1"@-"\'#At;$F$%ec?_?7f]FeVZE9;7fg@+r#5&Ai,QOM^_;7)J0tB\\!)EWe#!<"_%H(C)F+EES0*#;]r"a7C:l`;l1=i#20#3AP$u7PuK5*(B<<H6V2cUEmre@iD20_m[P$&9O^a0i)Y#5[/OB;n6paS-#jS7k.-l2tS7NoJ\\0W[Tjcsi!=8toA10!!miF9pM8E;F\\l/AOH/.XNNEV@0h1mSk4\'r<d)E90H1Q^qKW%b@Q^\\1Ik%5$cZQ@5Nk76^=-O>H\\B>7Z@TF;enKOkLlHGeVV#If7s_7WrL,g)2dDT(A_JB8Bc1>BBlUp`R-Q#>X<psQ5:j4/g5E^fN".qg<bH6DfQ>.!BoMFqc^AD`4#9fO/t-6Mb_TSca]lKO"=*%*[cq*f.?7neAVFHZW;^lFrOF3Mj_YkN%H1dn@k]SeoTXchV:p73\\m4nL%qK3]+QFkLM,>ZW9lr]Pdu=HU>LmE$Fum7I]5?pnj\']P@VPCTD4nh(fVW[MF&<?o4V27mR<0Jl]j=s?7]u07TQ:u))WFn3-DQ<@hZR(`0>\'5fe@.bu9\'m#\'Ers=\'CBu=1mRS\'[ff"O(Fn]^+4!>Pk^!T`dSR[]=3@KXd/#Gp!A.D&>o1)oOu.kmuoS$2JN0m_]hZ$:o@Xi6o]]X@BQEV.o-*b,*kYt?B0S.f1Wg,7Jq&WQS`"#,r1MG+4D(<bKEf/#3fVHYP*NfqXBj8#CXm-r/%..;,kjEP#*Xt0MG\\&;&&7M*NG$O72:o700=?$pupSDSl)a#^MQnk#(c0!VRiDunP5DXflHaT@h/90o]G*5$HSJ-mgq#h0>B\\0JY$_O>6HCu&k]N;N%$)T*u1^>J*@Vr=Y\'o%@U1@&KEQ&pob#CQ:<>[4$$9f2H6.o)0\\kM#`dBL\'bE)\'Nm:KNm>(s4+5.tr_\'<K"o_`_:2[CJo:;r]PDs92/K4Z\\5?jNhNQT!a>CLe~>'



__code__='Gat=(s)6X[\'RuIZ=keq<FCd/YR+W<e83#oB\'-MrF=ULAJ:bCLT16CVo?!FLmm@E_"<9eqt,_"^Ui\\0?*Zb<0(`2\'j348\\I&kKC4#754=WK<Cj2.fQ8p[pT@..geOl=2=@%!@%VC^^9MTjDU+h5l*>=*Pa\\N(>q3gH,\'U!7DSMF(BE=p]Ei`gE!c#^^h(=)J1H-l!+#^(&F^p[X+28oIKFa\'n2fL*J2`;Gddnf,4oFUar(5ZRN93C6=FkQZcG<\'c`/B+Qprn;%`9m\\U`_o=&i?eueT9B^/-k%=t=lchZf.Ut3(567KT!W[^i2H8lf[MFfK_.6;4&_Y]Ku6i1FEJJAkAgkg(3&AH\'=7p+DDDJ(/:I]WW+VQ"Z?G09!Vq@oX5M-l#S<seF%P"Ck:$VEMdZ/HU]+<_iVHTE)9k/K]2FDf/&N%d@8]WX>?%r!^86dqbINL/?!;46Sn,lf8I^"a(V?P1j*\'-g>;hj1\'N?8(>(p=eH#):%pROW>SSG07FIX$cZ^iE+j[V3lcP`gO[j>>pb@4%F[\\9&NrDGPW"[O&eAIt4tq_6=B,lDo\'5/&^Z;Q\\[TA>uZGgFTj,9!X6]#Jli$g)%l@"U>[_dN8l%AqNSIZ-5##rG^NIoUcQI\\8XeoM\'JE(\'&?fTi^g]7cHO!cXn*VqS\\r?4:YEi8h"IIYm("E_h_uU9]n8!nToQJ/c\'0_+H)q9+b4;=VE(ip(:7:Ad[b/ih1:aQA]JHU(gmP6fmG9OE&Df*i+B?6]FdBR1\'!6VRYi2(@V[ZW7D\\8652pFLd-Ij9iDRuhG<lsb@SXUQ5m=g8db4L\\-\\Obbo];p/?GCT;?DsjfW="QQibGURh9!qVIag+6[IrrpOF;\'^\\I7h`Cr2PogiE!E6ACib51e)gIg5j_=]&MhGhm7_\'>H$H<m@r\\5]Ba\'?B&/\'K4(4XMX8m^Y+*"t;gTS?)V\\XJ!,GS^rj?AR0`"k824#;AmXh*?Xf/3;dS&]SYHfIbt>)]Vr&,27lou9E;g4mK?rL#iMSOSP_9rIB$S!`RpjdG-_3V-*XaalmpcGCT;KhgEF^-AG3[ccuM(\'J\'/OK_V5Vm0.#1Y-SOfS+_m%o.8].I^=.=bO,E+3XBM\'=/B[nI#np>74n+[/T7gC1B]>)ZKh/etTP~>'



"""This module creates the RML PlugInFlowables for the Diagra documentation.

NB: No longer requires RML in this directory to work."""


import sys, os, rlextra
sys.path.insert(0,os.path.join(os.path.dirname(rlextra.__file__),'examples','graphics'))

from reportlab.graphics.charts.barcharts import VerticalBarChart
from reportlab.graphics.shapes import Drawing, String
from stackedBar import CylinderBarStacked
from slidebox import SlideBoxDrawing
from dotbox_db import DotBoxDrawing
from horizontalbarchart_db import HorizontalBarChartDrawing
from verticalbarchart_db import VerticalBarChartDrawing
#from linechart_db import LineChartDrawing

class RMLDotBox(DotBoxDrawing):
	def __init__(self,*args):
		DotBoxDrawing.__init__(self)
		self.hAlign='CENTER'
		if args: self._data = args[0]
	def wrap(self, w, h):
		self._sW=w
		return (self.width, self.height)
	def drawOn(self,canvas,x,y,_sW=0):
		DotBoxDrawing.drawOn(self, canvas, x, y, _sW=self._sW)

class RMLSlideBox(SlideBoxDrawing):
	def __init__(self,*args):
		SlideBoxDrawing.__init__(self)
		self.hAlign='CENTER'
		if args: self._data = args[0]
	def wrap(self, w, h):
		self._sW=w
		return (self.width, self.height)
	def drawOn(self,canvas,x,y,_sW=0):
		SlideBoxDrawing.drawOn(self, canvas, x, y, _sW=self._sW)

#class RMLLineChart(LineChartDrawing):
#	def __init__(self,data):
#		LineChartDrawing.__init__(self)
#		self.hAlign='CENTER'
#		self._data = data
#	def wrap(self, w, h):
#		self._sW=w
#		return (self.width, self.height)
#	def drawOn(self,canvas,x,y,_sW=0):
#		LineChartDrawing.drawOn(self, canvas, x, y, _sW=self._sW)

class RMLVerticalBarChart(VerticalBarChartDrawing):
	def __init__(self,*args):
		VerticalBarChartDrawing.__init__(self)
		self.hAlign='CENTER'
		if args: self._data = args[0]
	def wrap(self, w, h):
		self._sW=w
		return (self.width, self.height)
	def drawOn(self,canvas,x,y,_sW=0):
		VerticalBarChartDrawing.drawOn(self, canvas, x, y, _sW=self._sW)

class RMLHorizontalBarChart(HorizontalBarChartDrawing):
	def __init__(self,*args):
		HorizontalBarChartDrawing.__init__(self)
		self.hAlign='CENTER'
		if args: self._data = args[0]
	def wrap(self, w, h):
		self._sW=w
		return (self.width, self.height)
	def drawOn(self,canvas,x,y,_sW=0):
		HorizontalBarChartDrawing.drawOn(self, canvas, x, y, _sW=self._sW)

class RMLSymbolCylinderChart(CylinderBarStacked):
	def __init__(self,*args):
		CylinderBarStacked.__init__(self)
		self.hAlign='CENTER'
		if args: self._data = args[0]
	def wrap(self, w, h):
		self._sW=w
		return (self.width, self.height)
	def drawOn(self,canvas,x,y,_sW=0):
		CylinderBarStacked.drawOn(self, canvas, x, y, _sW=self._sW)

class RMLForceZeros(Drawing):
	def __init__(self, width=500,height=100, *nodes, **keywords):
		Drawing.__init__(self)
		self.add(VerticalBarChart(), 'vb1')
		self.vb1.data = [(50, 60, 70, 80, 90), (95, 55, 85, 65, 75)]
		self.vb1.valueAxis.forceZero=0
		self.vb1.x=20
		self.vb1.y=20
		self.add(VerticalBarChart(), 'vb2')
		self.vb2.data = [(50, 60, 70, 80, 90), (95, 55, 85, 65, 75)]
		self.vb2.valueAxis.forceZero=1
		self.vb2.x=250
		self.vb2.y=20
		self.transform = (0.75, 0, 0, 0.75, 0, 0)
		self.add(String(x=100, y=0,text="forceZero=0", fontName="Helvetica-Oblique", fontSize=8))
		self.add(String(x=300, y=0, text="forceZero=1", fontName="Helvetica-Oblique", fontSize=8))
		self.hAlign='CENTER'
	def wrap(self, w, h):
		self._sW=0.75*w
		return (0.75*self.width, 0.75*self.height)
	def drawOn(self,canvas,x,y,_sW=0):
		VerticalBarChart.draw(Onself, canvas, x, y, _sW=0.75*self._sW)
		



class ProxyFile:
    def __init__(self,file=None):
        self._L = []
        self._aL = self._L.append
        self._file = file
        self.hidden = 0

    def getValue(self):
        return ''.join(self._L)

    def flush(self): pass

    def really_flush(self):
        self._file.write(self.getValue())
        del self._L[:]

    def mark(self):
        return len(self._L)

    def write(self,s):
        if not self.hidden: self._aL(s)

    def pop(self,mark):
        L = self._L[mark:]
        if L: del self._L[mark:]
        return L

    def close(self):
        self.really_flush()
        del self._L, self._file, self._aL, self.hidden

class Stdout(ProxyFile):
    import sys
    def __init__(self):
        ProxyFile.__init__(self,self.sys.stdout)
        self._ostdout = self.sys.stdout
        self._ostderr = self.sys.stderr
        self.sys.stdout = self.sys.stderr = self

    def close(self):
        self.really_flush()
        self.restore()

    def restore(self):
        self.sys.stdout = self._ostdout
        self.sys.stderr = self._ostderr

#deletes its content when read
class MemFile:
    def __init__(self, value):
        self._value = value
    def read(self):
        value = self._value
        del self._value
        return value
    def write(self, value):
        self._value += value

if __name__=='__main__':
    stdout = Stdout()
    print('Hello World')
    print('Hello World Again')
    stdout.hidden = 1
    print('This should not appear')
    stdout.hidden = 0
    print('Hello World A Third Time')
    stdout.really_flush()
    stdout.close()
    print('This is normal printing')



__code__='Gas1];/[CB&>$Qs4,t7`f+!F#995B*NPrAATE9cXQ0Y/8(DG>9;n8RMj^s]]F2#9SXV9l^5,AlFr"8o45N?)G(HaEnnMR14Z$/_(h3m`$)=P%a_qaE9c(AZ]J!%R:0EV"e"X(Tr@!c_*8:VCn%(qu,%ak?Q@00V_28D92!al+L&[2Rd%WDaD4i$Z>(B@Zi(BN9@QN3?QhZpe&p]9<.J6)_8!rNo).c<2":B7R3bCp`ZF$9<c.f;oo(5uuNl^WO55h=lG"S)$nfR.SQF(2TZ5NPj7Pf!qIG!7FpAh[Sb=V]#Cb-D:&CIAnn=WO[LN(j42lrZlAf,ub[_:EGr(gr=b,iD5/j]<dBJ0PsZK2><G+1.tibVDh.^l\\Z^rQ8,Z1QM\\Fi[:`lIa5QjGoMgq#*8Wl*^9"Z`PRYb^=K;daC^?6Wkqk^XMW+jZsAKt0ZVklaOlCM"P\'/urop@P::9Z->\'3l:Q1);P$G*RGmR2h-et$V\'&N]/b@AG=gQ>mn#VJ(mRaK8/a9o5P%H*KT"Sl[a3Dk,`2iq8Jt]q"lFabab1>ff$>(>3ZY%#/B#,Y$qpi@nWJ+3??:g@_rA%JRuk%PukKUG.dL-IGR\'OTaB5[cdR3[8+L*Fq5&m**$lGrg"3CA&fq?JX\\b"I6X1q3_X!E;7<!lTd$Q\\8Ith/`.Sh8;37:)mNkJ";I,EWmGH+Sb5Y/Mp&*rV"n#$KEFq7\'CaFp1T=D&9q2Mr\'B;k9L;M?(ch-L_0TDESSI/BIXFGRe/-S!dA1[.`oqI"FEm[]V)2"%JnoC]fIDgCqGhEFA2MmZNh+&PB\'B>+67E6K]-1n94\\l]7[kZR*H[gq4Bgb$Zl]GH)/$[bK-_<BmPaiDrG3DXV#Jr2.p_BQ*cV,a!_.ad^gXZH)_#C#0oR@%ou9BKlriW,0j#"nT^5<s!Kb9YXsq]b\'9-nHse87^g_i/\'OXkU\'[<cb/@\\bBtiIA#+BEa$X3\'hm>+)&hn$s!h(\'dqN<u^BKpGOeIMFo<7-ZUd"jce8LnI@NMfFYYW9#uh`*OV\\(!EZeqEMA%N?:pfoco6)?ZM"_;LMCnMY\\4J/&nln)ufu`7qB%~>'
